# Piccolo

[![Build Status](https://travis-ci.com/piccolo-orm/piccolo.svg?branch=master)](https://travis-ci.com/piccolo-orm/piccolo)

[![Coverage Status](https://coveralls.io/repos/github/piccolo-orm/piccolo/badge.svg)](https://coveralls.io/github/piccolo-orm/piccolo)

A fast, user friendly ORM and query builder which supports asyncio.

Not production ready yet, but progressing quickly.

[Read the docs](https://piccolo-orm.readthedocs.io/en/latest/).
